@@ -190,6 +190,12 @@ func load(in io.Reader, conf *Config) error {
 				return fmt.Errorf(conf.Tr.Value("config.err.line", ln, err.Error()))
 			}
 			conf.Nvidia = nv
+		case nvidiarefresh:
+			d, err := time.ParseDuration(kv[1])
+			if err != nil {
+				return fmt.Errorf(conf.Tr.Value("config.err.line", ln, err.Error()))
+			}
+			conf.NvidiaRefresh = d
 		}
 	}
 
@@ -241,7 +247,7 @@ func marshal(c *Config) []byte {
 	fmt.Fprintf(buff, "%s=%t\n", averagecpu, c.AverageLoad)
 	fmt.Fprintln(buff, "# If true, show load per CPU")
 	fmt.Fprintf(buff, "%s=%t\n", percpuload, c.PercpuLoad)
-	fmt.Fprintln(buff, "# Temperature units. C for Celcius, F for Fahrenheit")
+	fmt.Fprintln(buff, "# Temperature units. C for Celsius, F for Fahrenheit")
 	fmt.Fprintf(buff, "%s=%c\n", tempscale, c.TempScale)
 	fmt.Fprintln(buff, "# If true, display a status bar")
 	fmt.Fprintf(buff, "%s=%t\n", statusbar, c.Statusbar)
@@ -286,4 +292,5 @@ const (
 	mbps                 = "mbps"
 	temperatures         = "temperatures"
 	nvidia               = "nvidia"
+	nvidiarefresh        = "nvidiarefresh"
 )
